﻿using System;
using System.Collections.Generic;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Text.RegularExpressions;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace Convertor
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();
        }

        #region Jednotky

        private readonly Jednotka[] _mira = new Jednotka[4]
        {
            new Jednotka(-3, "milimetr", "mm"),
            new Jednotka(-2, "centimetr", "cm"),
            new Jednotka(0, "metr", "m"),
            new Jednotka(3, "kilometr", "km")
        };

        private readonly Jednotka[] _vaha = new Jednotka[4]
        {
            new Jednotka(0, "kilogram", "kg"),
            new Jednotka(-3, "gram", "g"),
            new Jednotka(-2, "decagram", "dkg"),
            new Jednotka(3, "tuna", "t")
        };

        private readonly Jednotka[] _kapacita = new Jednotka[5]
        {
            new Jednotka(0, "byte", "B"),
            new Jednotka(3, "kilobyte", "KB"),
            new Jednotka(6, "megabyte", "MB"),
            new Jednotka(9, "gigabyte", "GB"),
            new Jednotka(12, "terabyte", "TB")
        };

        public Jednotka[] ZvolenaJednotka;
        #endregion

        /// <summary>
        /// Změní jazyk na vybraný 
        /// </summary>
        /// <param name="sender">Jaký jazyk byl zvolen</param>
        /// <param name="e"></param>
        private void ZmenaJazyka(object sender, RoutedEventArgs e)
        {

            ResourceDictionary rd = new ResourceDictionary();
            Application.Current.Resources.Clear();
            Application.Current.Resources.MergedDictionaries.Clear();
            switch (((Button) sender).Content.ToString())
            {
                case "Česky":
                    rd.Source = new Uri("\\Dicitonaries\\Cesky.xaml", UriKind.Relative);
                    break;

                case "English":
                    rd.Source = new Uri("\\Dicitonaries\\Anglicky.xaml", UriKind.Relative);
                    break;

                case "Español":
                    rd.Source = new Uri("\\Dicitonaries\\Spanelsky.xaml", UriKind.Relative);
                    break;
            }
            Application.Current.Resources.Source = rd.Source;
            Application.Current.Resources.MergedDictionaries.Add(rd);
            ReloadBox();
        }

        /// <summary>
        /// Zvýší nebo sníží číslo v textboxu
        /// </summary>
        /// <param name="sender">Ovládací tlačítko</param>
        /// <param name="e"></param>
        private void Button_Click(object sender, RoutedEventArgs e)
        {
            double cislo;

            switch (((Button) sender).Content.ToString())
            {
                case "˄":
                    if (double.TryParse(CisloBox.Text, NumberStyles.Any, CultureInfo.CurrentCulture, out cislo))
                        CisloBox.Text = (++cislo).ToString("F", CultureInfo.CurrentCulture);
                    break;

                case "˅":
                    if (double.TryParse(CisloBox.Text, NumberStyles.Any, CultureInfo.CurrentCulture, out cislo))
                        CisloBox.Text = (--cislo).ToString("F", CultureInfo.CurrentCulture);
                    break;
            }
        }

        /// <summary>
        /// Validace textu v boxu
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        private void CisloBox_TextChanged(object sender, TextChangedEventArgs e)
        {
            if (!Regex.IsMatch(CisloBox.Text, "^[0123456789,-]+$") ||
                CisloBox.Text.Count(znak => znak == ',') > 1 ||
                !char.IsDigit(CisloBox.Text[CisloBox.Text.Length - 1]))
                CisloBox.Foreground = Brushes.Red;
            // pokud text obsahuje nepovolený znak nebo je tam příliš mnoho desetinných čárek/teček nebo posledním znakem není číslo

            else
                CisloBox.Foreground = (SolidColorBrush) (new BrushConverter().ConvertFrom("#FF2D2D30"));

            if (!Equals(CisloBox.Foreground, Brushes.Red)) //pokud je vstupní pole zadáno správně tak spusť převádění
                Prevod();
        }

        private void Prevod()
        {
            if (PrevestZBox.SelectedIndex == -1 || PrevestDoBox.SelectedIndex == -1) return; //ošetření před chybou

            double input = double.Parse(CisloBox.Text);
            double zaklad = input*Math.Pow(10, ZvolenaJednotka[PrevestZBox.SelectedIndex].Nasobitel); // převod na základní jednotku
            VysledekTextBox.Text =
                (zaklad*Math.Pow(10, -ZvolenaJednotka[PrevestDoBox.SelectedIndex].Nasobitel)).ToString();
                //převod ze základní jednotky
        }

        private void Window_Loaded(object sender, RoutedEventArgs e)
        {
            //nahrání systémové lokalizace
            string lokalizace = Thread.CurrentThread.CurrentCulture.ToString();
            ResourceDictionary rd = new ResourceDictionary();
            Application.Current.Resources.Clear();
            Application.Current.Resources.MergedDictionaries.Clear();

            if (lokalizace.Contains("cs")) //kontrola pro český jazyk
                rd.Source = new Uri("\\Dicitonaries\\Cesky.xaml", UriKind.Relative);

            else if (lokalizace.Contains("es")) //kontrola pro španělský jazyk
                rd.Source = new Uri("\\Dicitonaries\\Spanelsky.xaml", UriKind.Relative);

            else //pro všechny osatní kultury se spustí angličtina
                rd.Source = new Uri("\\Dicitonaries\\Anglicky.xaml", UriKind.Relative);

            Application.Current.Resources.Source = rd.Source;
            Application.Current.Resources.MergedDictionaries.Add(rd);

            //nastavení jednotek míry jako defaultní
            ZvolenaJednotka = _mira;
            ReloadBox();
        }

        /// <summary>
        /// Změní jednotky podle tlačítka
        /// </summary>
        /// <param name="sender">Tlačítko na které bylo kliknuto</param>
        /// <param name="e"></param>
        private void ZmenaJednotek(object sender, RoutedEventArgs e)
        {
            switch (((Button) sender).Tag.ToString())
            {
                case "mira":
                    ZvolenaJednotka = _mira;
                    break;

                case "vaha":
                    ZvolenaJednotka = _vaha;
                    break;

                case "kapacita":
                    ZvolenaJednotka = _kapacita;
                    break;
            }
            ReloadBox();
        }

        private void ReloadBox()
        {
          PrevestZBox.Items.Clear();
          PrevestDoBox.Items.Clear();

            foreach (var item in ZvolenaJednotka)
            {
                PrevestZBox.Items.Add(item.Popisek);
                PrevestDoBox.Items.Add(item.Popisek);
            }
            
            PrevestZBox.SelectedIndex = PrevestDoBox.SelectedIndex = 0;
        }

        private void Box_SelectionChanged(object sender, SelectionChangedEventArgs e)
        {
            if (!Equals(CisloBox.Foreground, Brushes.Red)) //pokud je vstupní pole zadáno správně tak spusť převádění
                Prevod();
        }
    }
}
