﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Globalization;
using System.Runtime.Remoting;

namespace PrevodnikJednotek
{
    /// <summary>
    /// Interaction logic for MainWindow.xaml
    /// </summary>
    public partial class MainWindow : Window
    {
        /// <summary>
        /// Stores convertor
        /// </summary>
        IConvertor convertor;
        /// <summary>
        /// Constructor for MainWindow
        /// </summary>
        public MainWindow()
        {
            InitializeComponent();
            convertor = new MeasuresConvertor();
            measuresMenuItem.IsEnabled = false;
            
            IEnumerable<MenuItem> mItem = languageMenuItem.Items.OfType<MenuItem>().Where(x => 
                ((string)x.DataContext).Contains(Thread.CurrentThread.CurrentUICulture.Name.Split('-')[0]));
            if (mItem != null)
                mItem.Single().IsEnabled = false;
            else
                czechMenuItem.IsEnabled = false;

            ReloadComboBox();
            ReloadTexts();
        }
        /// <summary>
        /// Change language of application
        /// </summary>
        /// <param name="sender">Sender item</param>
        /// <param name="e">Event arguments</param>
        private void changeLanguage(object sender, RoutedEventArgs e)
        {
            MenuItem selectedItem = (MenuItem)sender;
            // Activate all menu items and disable selected item
            foreach (MenuItem item in languageMenuItem.Items)
            {
                item.IsEnabled = true;
            }
            selectedItem.IsEnabled = false;
            // Change culture info of application
            Thread.CurrentThread.CurrentUICulture = CultureInfo.GetCultureInfo((string)selectedItem.DataContext);
            ReloadTexts();
        }
        /// <summary>
        /// Change convertor which is used for converting units
        /// </summary>
        /// <param name="sender">Sender item</param>
        /// <param name="e">Event arguments</param>
        private void changeConvertor(object sender, RoutedEventArgs e)
        {
            MenuItem selectedItem = (MenuItem)sender;
            // Activate all menu items and disable selected item 
            foreach (MenuItem item in menu.Items)
            {
                item.IsEnabled = true;
            }
            selectedItem.IsEnabled = false;
            // Change convertor and reload ComboBoxs
            convertor = (IConvertor)Activator.CreateInstance("Převodník jednotek", "PrevodnikJednotek." + (string)selectedItem.DataContext).Unwrap();
            ReloadComboBox();
        }
        /// <summary>
        /// Reload texts
        /// </summary>
        private void ReloadTexts()
        {
            languageMenuItem.Header = strings.Language;
            measuresMenuItem.Header = strings.Measures;
            weightsMenuItem.Header = strings.Weights;
            dataUnitsMenuItem.Header = strings.DataUnits;
            czechMenuItem.Header = strings.Czech;
            englishMenuItem.Header = strings.English;
            germanMenuItem.Header = strings.German;
            convertFromTextBlock.Text = strings.ConvertFrom;
            converToTextBlock.Text = strings.ConvertTo;
            convertButton.Content = strings.Convert;
            this.Title = strings.Title;
        }
        /// <summary>
        /// Reload ComboBoxs
        /// </summary>
        public void ReloadComboBox()
        {
            unitsFromComboBox.DataContext = unitsToComboBox.DataContext = convertor.GetUnits();
            unitsFromComboBox.SelectedIndex = 0;
            unitsToComboBox.SelectedIndex = 0;
        }
        /// <summary>
        /// Convert input
        /// </summary>
        /// <param name="sender">Sender item</param>
        /// <param name="e">Event arguments</param>
        private void convertButton_Click(object sender, RoutedEventArgs e)
        {
            double input;
            if (double.TryParse(inputTextBox.Text, out input))
            {
                double result = convertor.Convert(input, ((int)unitsFromComboBox.SelectedValue), ((int)unitsToComboBox.SelectedValue));
                resultTextBlock.Text = result.ToString();
            }
            else
                resultTextBlock.Text = strings.Error;
        }
    }
}
