﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Globalization;

namespace UnitConverter
{
    /// <summary>
    /// Trieda reprezentuje Správcu jazykovej lokalizácie aplikácie.
    /// </summary>
    class LanguageManager
    {
        public UIHelper UIHelper { get; private set; }
        public Translator Translator { get; private set; }
        public QuantitiesReader QuantitiesReader { get; private set; }
        
        public List<string> KeywordsList { get; private set; }
        public string InputLanguage { get; private set; }
        public int QuantityCombo_SelectedIndex_LAST { get; private set; }
        public bool IsTranslating { get; private set; }

        public LanguageManager(UIHelper uiHelper)
        {
            UIHelper = uiHelper;
            Translator = new Translator();
            QuantitiesReader = new QuantitiesReader("quantities.xml");

            KeywordsList = new List<string> { "Settings", "Please select a language:", "Quantity:", "Convert from:", "Convert to:", "Created by", "Convert!" };
            InputLanguage = "en";
        }

        public void TranslateUI(bool IsStart)
        {
            if (!UIHelper.IsRenderingUI)
                return;

            IsTranslating = true;

            string outputLanguage;
            if (IsStart)
            {
                outputLanguage = GetActuallyRunTimeLanguage();
                UIHelper.LanguageCombo_SelectedItem = Translator.GetLanguageNameByKey(outputLanguage);
                UIHelper.QuantityCombo_SelectedIndex = 0;
            }
            else
                outputLanguage = Translator.GetKeyByLanguageName(UIHelper.LanguageCombo_SelectedItem);

            UIHelper.PropertiesGroupBox_Header = Translator.Translate(KeywordsList[0], InputLanguage, outputLanguage);
            UIHelper.LanguageLabel_Content = Translator.Translate(KeywordsList[1], InputLanguage, outputLanguage);
            UIHelper.QuantityLabel_Content = Translator.Translate(KeywordsList[2], InputLanguage, outputLanguage);

            List<string> QuantityCombo_Items_Translated = new List<string>();

            foreach (string s in QuantitiesReader.GetListOfQuantities())
                QuantityCombo_Items_Translated.Add(Translator.Translate(s, InputLanguage, outputLanguage));

            QuantityCombo_SelectedIndex_LAST = UIHelper.QuantityCombo_SelectedIndex;
            UIHelper.QuantityCombo_Items = QuantityCombo_Items_Translated;
            
            UIHelper.FromLabel_Content = Translator.Translate(KeywordsList[3], InputLanguage, outputLanguage);
            UIHelper.ToLabel_Content = Translator.Translate(KeywordsList[4], InputLanguage, outputLanguage);
            UIHelper.StatusBar_Items = Translator.Translate(KeywordsList[5], InputLanguage, outputLanguage);
            UIHelper.ConvertButton_Content = Translator.Translate(KeywordsList[6], InputLanguage, outputLanguage);

            IsTranslating = false;
        }

        private string GetActuallyRunTimeLanguage()
        {
            return CultureInfo.CurrentUICulture.TwoLetterISOLanguageName; //CultureInfo.CurrentCulture.TwoLetterISOLanguageName;
        }
    }
}
