﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows.Controls;

namespace UnitConverter
{
    /// <summary>
    /// Trieda reprezentuje Pomocník pri práci z užívateľským prostredím.
    /// </summary>
    class UIHelper
    {
        public MainWindow MainWindow { get; private set; }
        public Translator Translator { get; private set; }
        public QuantitiesReader QuantitiesReader { get; private set; }
        public LanguageManager LanguageManager { get; private set; }

        public bool IsRenderingUI { get; private set; }

        public string PropertiesGroupBox_Header { get { return (string)MainWindow.propertiesGroupBox.Header; } set { MainWindow.propertiesGroupBox.Header = value; } }

        public string LanguageLabel_Content { get { return (string)MainWindow.languageLabel.Content; } set { MainWindow.languageLabel.Content = value; } }
        public List<string> LanguageCombo_Items { get { return (List<string>)MainWindow.languageCombo.ItemsSource; } set { MainWindow.languageCombo.ItemsSource = value; } }
        public string LanguageCombo_SelectedItem { get { return (string)MainWindow.languageCombo.SelectedItem; } set { MainWindow.languageCombo.SelectedItem = value; } }

        public string QuantityLabel_Content { get { return (string)MainWindow.quantityLabel.Content; } set { MainWindow.quantityLabel.Content = value; } }
        public List<string> QuantityCombo_Items { get { return (List<string>)MainWindow.quantityCombo.ItemsSource; } set { MainWindow.quantityCombo.ItemsSource = value; } }
        public int QuantityCombo_SelectedIndex { get { return MainWindow.quantityCombo.SelectedIndex; } set { MainWindow.quantityCombo.SelectedIndex = value; } }

        public string FromLabel_Content { get { return (string)MainWindow.fromLabel.Content; } set { MainWindow.fromLabel.Content = value; } }
        public string FromTextBox_Text { get { return MainWindow.fromTextBox.Text; } private set { } }
        public List<string> FromCombo_Items { get { return (List<string>)MainWindow.fromCombo.ItemsSource; } set { MainWindow.fromCombo.ItemsSource = value; } }
        public string FromCombo_SelectedItem { get { return (string)MainWindow.fromCombo.SelectedItem; } set { MainWindow.fromCombo.SelectedItem = value; } }

        public string ToLabel_Content { get { return (string)MainWindow.toLabel.Content; } set { MainWindow.toLabel.Content = value; } }
        public string ToTextBox_Text { get { return MainWindow.toTextBox.Text; } set { MainWindow.toTextBox.Text = value; } }
        public List<string> ToCombo_Items { get { return (List<string>)MainWindow.toCombo.ItemsSource; } set { MainWindow.toCombo.ItemsSource = value; } }
        public string ToCombo_SelectedItem { get { return (string)MainWindow.toCombo.SelectedItem; } set { MainWindow.toCombo.SelectedItem = value; } }

        public string StatusBar_Items 
        { 
            get 
            { 
                return ""; 
            } 
            set 
            {
                TextBlock textBlockConstant = new TextBlock();
                textBlockConstant.Text = "Unit Converter";
                Separator separator = new Separator();
                TextBlock textBlockCustom = new TextBlock();
                textBlockCustom.Text = value + " Štefan Pružinský";

                MainWindow.statusBar.Items.Clear();
                MainWindow.statusBar.Items.Add(textBlockConstant);
                MainWindow.statusBar.Items.Add(separator);
                MainWindow.statusBar.Items.Add(textBlockCustom);
            } 
        }

        public string ConvertButton_Content { get { return (string)MainWindow.convertButton.Content; } set { MainWindow.convertButton.Content = value; } }

        public UIHelper(MainWindow mainWindow)
        {
            MainWindow = mainWindow;

            Translator = new Translator();
            QuantitiesReader = new QuantitiesReader("quantities.xml");
            LanguageManager = new LanguageManager(this);
            
            IsRenderingUI = true;
        }

        public void RenderUI()
        {
            QuantityCombo_Items = new List<string> { "" };
            LanguageManager.TranslateUI(true);

            ToCombo_SelectedItem = QuantitiesReader.GetValueOfMainUnit(QuantityCombo_SelectedIndex);
            FromCombo_SelectedItem = QuantitiesReader.GetValueOfMainUnit(QuantityCombo_SelectedIndex);

            IsRenderingUI = false;
            LanguageCombo_Items = Translator.GetListOfLanguages();
            IsRenderingUI = true;

            FromCombo_Items = QuantitiesReader.GetListOfQuantityValues(QuantityCombo_SelectedIndex);
            ToCombo_Items = QuantitiesReader.GetListOfQuantityValues(QuantityCombo_SelectedIndex);
        }

        public void QuantityCombo_SelectionChanged_ChangeUnits()
        {
            if (LanguageManager.IsTranslating)
            {
                QuantityCombo_SelectedIndex = LanguageManager.QuantityCombo_SelectedIndex_LAST;
            }

            ToCombo_SelectedItem = QuantitiesReader.GetValueOfMainUnit(QuantityCombo_SelectedIndex);
            FromCombo_SelectedItem = QuantitiesReader.GetValueOfMainUnit(QuantityCombo_SelectedIndex);

            FromCombo_Items = QuantitiesReader.GetListOfQuantityValues(QuantityCombo_SelectedIndex);
            ToCombo_Items = QuantitiesReader.GetListOfQuantityValues(QuantityCombo_SelectedIndex);
        }
    }
}
