﻿using System;
using System.Collections.Generic;
using System.Windows.Forms;

namespace Konvertor
{
    public partial class HlavniFormular : Form
    {
        private readonly Konfigurator _konfigurace;
        private string _vybranyJazyk;
        private readonly Konvertor _konvertor;
        private List<Jednotka> _jednotky; 
        public HlavniFormular(Konfigurator konfigurace)
        {
            _konfigurace = konfigurace;
            _konvertor = new Konvertor();
            InitializeComponent();
            NactiJazyk();
        }

        /// <summary>
        /// Lokalizuje prvky na formulary
        /// </summary>
        public void NactiJazyk()
        {
            Text = Prekladac.Preloz("nazev");
            cmb_jazyk.Items.Clear();
            foreach (KeyValuePair<string, string> jazyk in Prekladac.DostupneJazyky())
            {
                cmb_jazyk.Items.Add(jazyk.Key);
                if (jazyk.Value == Prekladac.Jazyk)
                {
                    _vybranyJazyk = jazyk.Key;
                    cmb_jazyk.Text = jazyk.Key;
                }
            }
            cmb_skupina.Items.Clear();
            foreach (Velicina velicina in _konvertor.Veliciny){
                cmb_skupina.Items.Add(velicina.Nazev);
            }
            cmb_skupina.Text = Prekladac.Preloz("vaha");
            lbl_z_hodnota.Text = Prekladac.Preloz("prevod_z") + ":";
            lbl_do_hodnota.Text = Prekladac.Preloz("prevod_do") + ":";
        }

        /// <summary>
        /// Vyvola zmenu jazyku
        /// </summary>
        /// <param name="sender">odesilatel</param>
        /// <param name="e">argumenty udalosti</param>
        private void cmb_jazyk_SelectedIndexChanged(object sender, EventArgs e)
        {
            //zabranime pripadnemu rekurzivnimu zacykleni kde by se vlivem zmeni cmb mohla znovu a znovu vyvolavat zmena jazyka
            if(_vybranyJazyk == cmb_jazyk.Text || cmb_jazyk.Text == "")
                return;
            //najde jazyk na ktery prepne
            foreach (KeyValuePair<string, string> jazyk in Prekladac.DostupneJazyky()){
                if (jazyk.Key == cmb_jazyk.Text){
                    _konfigurace.ZmenJazyk(jazyk.Value);
                    NactiJazyk();
                }
            }
        }

        /// <summary>
        /// Prenastavy selecty na povolene jednoky
        /// </summary>
        /// <param name="sender">odesilatel</param>
        /// <param name="e">argumenty udalosti</param>
        private void cmb_skupina_SelectedIndexChanged(object sender, EventArgs e)
        {
            string znacka;
            Velicina velicina = _konvertor.Veliciny[0];
            if (cmb_skupina.SelectedIndex < _konvertor.Veliciny.Count)
                velicina = _konvertor.Veliciny[cmb_skupina.SelectedIndex];
            _jednotky = velicina.Jednotky;
            znacka = velicina.Znacka;
            cmb_do_jednotka.Items.Clear();
            cmb_z_jednotka.Items.Clear();
            cmb_z_jednotka.Text = "";
            cmb_do_jednotka.Text = "";
            txb_do_hodnota.Text = "";
            txb_z_hodnota.Text = "";
            foreach (Jednotka jednotka in _jednotky)
            {
                cmb_do_jednotka.Items.Add(jednotka.Vypis(znacka));
                cmb_z_jednotka.Items.Add(jednotka.Vypis(znacka));
            }
        }

        /// <summary>
        /// Pokusi se zkonvertovat
        /// </summary>
        /// <param name="sender">odesilatel</param>
        /// <param name="e">argumenty udalosti</param>
        private void Konvertuj(object sender, EventArgs e)
        {
            if (cmb_do_jednotka.Text != "" && cmb_z_jednotka.Text != ""){
                int hodnota;
                int.TryParse(txb_z_hodnota.Text, out hodnota);
                txb_do_hodnota.Text = _konvertor.Konvertuj(hodnota, _jednotky[cmb_z_jednotka.SelectedIndex], _jednotky[cmb_do_jednotka.SelectedIndex]);
            }
            else{
                txb_do_hodnota.Text = "";
            }
        }
    }
}
