﻿using System;
using System.Collections.Generic;

namespace Konvertor
{
    class ModKonzole
    {
        private Konvertor _konvertor;
        private readonly Konfigurator _konfigurace;
        public ModKonzole(Konfigurator konfigurace)
        {
            _konfigurace = konfigurace;
        }

        /// <summary>
        /// tady je live cyklus pro konzolovy mod
        /// </summary>
        public void Spustit()
        {
            _konvertor = new Konvertor();
            int volba = 0;
            while (true)
            {
                if (volba == -1){
                    return;
                }
                VypisLinku("-");
                Console.WriteLine(Prekladac.Preloz("nazev") + " - " + Prekladac.Preloz("konzolemod"));
                VypisLinku("-");
                Console.WriteLine();
                switch (volba){
                    case 0:
                        Console.WriteLine("0) " + Prekladac.Preloz("konec"));
                        Console.WriteLine("1) " + Prekladac.Preloz("zmenjazyk"));
                        Console.WriteLine("2) " + Prekladac.Preloz("nazev"));
                        string vstup = Console.ReadLine();
                        switch (vstup){
                            case "0":
                                return;
                            case "1":
                                volba = 1;
                                break;
                            case "2":
                                volba = 2;
                                break;
                        }
                        break;
                    case 1:
                        ZmenaJazyku();
                        volba = 0;
                        break;
                    case 2:
                        volba = Konvertor();
                        break;
                    default:
                        Console.WriteLine(Prekladac.Preloz("spatnavolba"));
                        volba = 0;
                        break;
                }
            }
        }

        /// <summary>
        /// Vypise konvertor
        /// </summary>
        /// <returns>Status s kterym nalozi materska metoda</returns>
        private int Konvertor()
        {
            Console.WriteLine("0) " + Prekladac.Preloz("zpet"));
            Console.WriteLine("1) " + Prekladac.Preloz("konec"));
            Console.WriteLine("2) " + Prekladac.Preloz("vaha"));
            Console.WriteLine("3) " + Prekladac.Preloz("vzdalenost"));
            Console.WriteLine("4) " + Prekladac.Preloz("bajty"));
            string vstup = Console.ReadLine();
            int volba;
            int.TryParse(vstup, out volba);
            if (vstup == "0")
                return 0;
            if (volba == 0){
                Console.WriteLine(Prekladac.Preloz("zadejte_cislo"));
                return 2;
            }
            if (volba == 1)
                return -1;
            volba -= 2;
            if (volba >= _konvertor.Veliciny.Count){
                Console.WriteLine(Prekladac.Preloz("zadejte_cislo"));
                return 2;
            }
            VypisKonvertor(_konvertor.Veliciny[volba]);
            return 2;
        }

        /// <summary>
        /// Stara se jiz o jednu velicinu
        /// </summary>
        /// <param name="velicina">pro kterou velicinu vypsat</param>
        private void VypisKonvertor(Velicina velicina)
        {
            VypisLinku("-");
            Console.WriteLine(velicina.Nazev);
            VypisLinku("-");
            Console.WriteLine();
            List<Jednotka> jednotky = velicina.Jednotky;
            Jednotka zJednotky = VyberJednotky(jednotky, Prekladac.Preloz("volba_z"), velicina.Znacka);
            Jednotka doJednotky = VyberJednotky(jednotky, Prekladac.Preloz("volba_do"), velicina.Znacka);
            decimal hodnota = ZiskejCislo();
            string vysledek = _konvertor.Konvertuj(hodnota, zJednotky, doJednotky);
            Console.WriteLine(hodnota + zJednotky.Vypis(velicina.Znacka) + " = " + vysledek + doJednotky.Vypis(velicina.Znacka));
        }

        /// <summary>
        /// Pokusi se ziskat z uzivatele nejake cislo
        /// </summary>
        /// <returns>Ziskane cislo</returns>
        private decimal ZiskejCislo()
        {
            while (true){
                Console.Write(Prekladac.Preloz("co_prevest") + ": ");
                try{
                    decimal vysledek = Convert.ToDecimal(Console.ReadLine());
                    return vysledek;
                }
                catch (Exception){
                    Console.WriteLine(Prekladac.Preloz("zedej_cislo"));
                    Console.WriteLine();
                }
            }

        }

        /// <summary>
        /// Ziska od uzivatele vyber jednotky pro prevod
        /// </summary>
        /// <param name="jednotky">List veskerych moznych jednotek</param>
        /// <param name="zprava">Dotaz ktery na metoda pokladat</param>
        /// <param name="znacka">Znacka veliziny</param>
        /// <returns></returns>
        private Jednotka VyberJednotky(List<Jednotka> jednotky, string zprava, string znacka)
        {
            while (true){
                Console.WriteLine(zprava);
                int i = 1;
                foreach (Jednotka jednotka in jednotky){
                    Console.WriteLine(i + ") " + jednotka.Vypis(znacka));
                    i++;
                }
                int volba;
                int.TryParse(Console.ReadLine(), out volba);
                Console.WriteLine();
                if (volba > 0 && volba <= jednotky.Count)
                    return jednotky[volba - 1];
                Console.WriteLine(Prekladac.Preloz("zadejte_cislo"));
                Console.WriteLine();
            }
        }

        /// <summary>
        /// Umozni uzivateli zmenit jazyk aplikace
        /// </summary>
        private void ZmenaJazyku()
        {
            Console.WriteLine(Prekladac.Preloz("dostupnejazyky"));
            VypisLinku("=");
            Console.WriteLine();
            Console.WriteLine("0) " + Prekladac.Preloz("zpet"));
            int i = 1;
            List<string> jaz = new List<string>();
            foreach (KeyValuePair<string, string> jazyky in Prekladac.DostupneJazyky())
            {
                Console.WriteLine(i + ") " + jazyky.Key);
                jaz.Add(jazyky.Value);
                i++;
            }
            int volba;
            int.TryParse(Console.ReadLine(), out volba);
            if(volba == 0)
                return;
            _konfigurace.ZmenJazyk(jaz[volba - 1]);
        }

        /// <summary>
        /// Pro graficke uceli vykresli do konzole linku. Musi zacinat na zacatku radku
        /// </summary>
        /// <param name="znaky">Znaky pro opakovani</param>
        private void VypisLinku(string znaky)
        {
            for (int i = 0; i < (Console.WindowWidth)/znaky.Length; i++){
                Console.Write(znaky);
            }
            for (int i = 0; i < (Console.WindowWidth)%znaky.Length; i++){
                Console.Write(znaky[i]);
            }
        }
    }
}
