﻿using System;
using System.Collections.Generic;
using System.IO;

namespace Konvertor
{
    class Prekladac
    {
        /// <summary>
        /// Aktualni jazyk pro preklad
        /// </summary>
        public static string Jazyk { get; private set; }
        private static Dictionary<string, string> _preklady;
        private static Konfigurator _konfigurace;

        /// <summary>
        /// Inicializuje preklady
        /// </summary>
        /// <param name="konfigurace">konfiguracni objekt</param>
        public static void Inicializuj(Konfigurator konfigurace)
        {
            _preklady = new Dictionary<string, string>();
            _konfigurace = konfigurace;
            NactiJazyk();
        }

        /// <summary>
        /// Vrati dostupne jazyky v lokalizovane podobe
        /// </summary>
        /// <returns>Dostupne jazyky (preklad,hodnota)</returns>
        public static Dictionary<string, string> DostupneJazyky()
        {
            Dictionary<string,string> jazyky = new Dictionary<string, string>();
            foreach (KeyValuePair<string, string> nelokalizovaneJazyky in _konfigurace.Jazyky){
                jazyky[Preloz(nelokalizovaneJazyky.Key)] = nelokalizovaneJazyky.Value;
            }
            return jazyky;
        }

        /// <summary>
        /// Vrati lokalizovanou verzi klice
        /// </summary>
        /// <param name="klic">Klic ktery odpovida klici v lokalizacnim souboru</param>
        /// <param name="rekurze">true -> nevypise se lokalizovana chybova hlaska</param>
        /// <returns>Lokalizovany string</returns>
        public static string Preloz(string klic, bool rekurze = false)
        {
            //prenastavil se jazyk
            if(Jazyk != _konfigurace.Lokalizace)
                NactiJazyk();
            //nastane jen v pripade ze si nekdo bude hrat s kodem
            if(_preklady == null)
                throw new Exception("Preklady nejsou inicializovany");
            if (_preklady.ContainsKey(klic))
                return _preklady[klic];
            //protoze vyuzivame rekurzivniho volani v pripade chyby je nutne zajistit aby pri chybejici chybove hlasce nedoslo k zacykleni
            if (rekurze)
                return klic + " Preklad nenalezen";
            return klic + " " + Preloz("prekladnenalezen", true);
        }

        /// <summary>
        /// Nacte jazyk ze souboru do Dictionary
        /// </summary>
        private static void NactiJazyk()
        {
            Jazyk = _konfigurace.Lokalizace;
            if (File.Exists(_konfigurace.CestaKLokalizaci))
            {
                using (StreamReader sr = new StreamReader(_konfigurace.CestaKLokalizaci)){
                    sr.ReadLine();
                    while (!sr.EndOfStream){
                        string line = sr.ReadLine();
                        //kontrola zda-li je vubec co rozdelovat a jestli axistuje klic ke kteremu se bude prirazovat (hodnota muze byt prazdna)
                        if (line != null && line.Contains("=") && line[0] != '='){
                            string[] val = line.Split('=');
                            _preklady[val[0]] = val[1];
                        }
                    }
                }
            }
            else{
                //nekde se ztratil soubor uzivateluv problem
                throw new Exception("Soubor lokalizace neexistuje " + _konfigurace.CestaKLokalizaci);
            }
        }
    }
}
